import numeral from 'numeral'

type FormatRawFileSize = (maybeNumber: unknown) => string

const formatRawFileSize: FormatRawFileSize = maybeNumber => {
    if (typeof maybeNumber! !== 'number') {
        throw TypeError('Argument should be a number.')
    }

    const n = maybeNumber as number

    if (isNaN(n)) {
        throw RangeError('Cannot format NaN.')
    }

    const absValue = Math.abs(n)
    const base = numeral(absValue < 1000 ? absValue : 999).format('0 b')
    const suffix = base.slice(base.indexOf(' ') + ' '.length)
    return `${n < 0 ? '-' : ''}${numeral(absValue).format('0,0')} ${suffix}`
}

export default formatRawFileSize
